/*!
 * Copyright (c) Microsoft Corporation and contributors. All rights reserved.
 * Licensed under the MIT License.
 */
import { TypedEventEmitter } from "@fluid-internal/client-utils";
import type { IDeltaManager, IDeltaManagerEvents, IDeltaQueue, IDeltaSender, ReadOnlyInfo } from "@fluidframework/container-definitions";
import { IClientConfiguration, IClientDetails, IDocumentMessage, ISequencedDocumentMessage, ISignalMessage } from "@fluidframework/protocol-definitions";
/**
 * Proxy to the real IDeltaManager for restricting certain access to layers below container runtime in summarizer clients:
 * - Summarizer client should be read-only to layers below the container runtime to restrict local changes.
 * - Summarizer client should not be active to layers below the container runtime to restrict local changes.
 */
export declare class DeltaManagerSummarizerProxy extends TypedEventEmitter<IDeltaManagerEvents> implements IDeltaManager<ISequencedDocumentMessage, IDocumentMessage> {
    private readonly deltaManager;
    get IDeltaSender(): IDeltaSender;
    get inbound(): IDeltaQueue<ISequencedDocumentMessage>;
    get outbound(): IDeltaQueue<IDocumentMessage[]>;
    get inboundSignal(): IDeltaQueue<ISignalMessage>;
    get minimumSequenceNumber(): number;
    get lastSequenceNumber(): number;
    get lastMessage(): ISequencedDocumentMessage | undefined;
    get lastKnownSeqNumber(): number;
    get initialSequenceNumber(): number;
    get hasCheckpointSequenceNumber(): boolean;
    get clientDetails(): IClientDetails;
    get version(): string;
    get maxMessageSize(): number;
    get serviceConfiguration(): IClientConfiguration | undefined;
    get active(): boolean;
    get readOnlyInfo(): ReadOnlyInfo;
    private readonly isSummarizerClient;
    constructor(deltaManager: IDeltaManager<ISequencedDocumentMessage, IDocumentMessage>);
    dispose(): void;
    submitSignal(content: string, targetClientId?: string): void;
    flush(): void;
    private readonly onPrepareSend;
    private readonly onSubmitOp;
    private readonly onOp;
    private readonly onPong;
    private readonly onConnect;
    private readonly onDisconnect;
    private readonly onReadonly;
}
//# sourceMappingURL=deltaManagerSummarizerProxy.d.ts.map