/*!
 * Copyright (c) Microsoft Corporation and contributors. All rights reserved.
 * Licensed under the MIT License.
 */
import { IDataStore, IFluidDataStoreChannel } from "@fluidframework/runtime-definitions/internal";
import { ITelemetryLoggerExt } from "@fluidframework/telemetry-utils";
import { ChannelCollection } from "./channelCollection.js";
/**
 * Interface for an op to be used for assigning an
 * alias to a datastore
 */
export interface IDataStoreAliasMessage {
    /** The internal id of the datastore */
    readonly internalId: string;
    /** The alias name to be assigned to the datastore */
    readonly alias: string;
}
/**
 * Type guard that returns true if the given alias message is actually an instance of
 * a class which implements {@link IDataStoreAliasMessage}
 * @param maybeDataStoreAliasMessage - message object to be validated
 * @returns True if the {@link IDataStoreAliasMessage} is fully implemented, false otherwise
 */
export declare const isDataStoreAliasMessage: (maybeDataStoreAliasMessage: any) => maybeDataStoreAliasMessage is IDataStoreAliasMessage;
export declare const channelToDataStore: (fluidDataStoreChannel: IFluidDataStoreChannel, internalId: string, channelCollection: ChannelCollection, logger: ITelemetryLoggerExt) => IDataStore;
//# sourceMappingURL=dataStore.d.ts.map